@@ -1,14 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import cmd
 import os
 
 from particle import Particle
 
-
 DIR = os.path.dirname(__file__)
 
 known_models = [
