@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-from .decay import DaughtersDict, DecayMode, DecayChain
-
+from .decay import DaughtersDict, DecayChain, DecayMode
 from .viewer import DecayChainViewer
 
 __all__ = ("DaughtersDict", "DecayMode", "DecayChain", "DecayChainViewer")
