@@ -4,8 +4,7 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
 
-from __future__ import absolute_import
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
 from collections import Counter
 from copy import deepcopy
@@ -607,6 +606,11 @@ class DecayChain(object):
             If provided, ignores the sub-decays of the listed particles,
             considering them as stable.
 
+        Note
+        ----
+        After flattening the only `DecayMode` metadata kept is that of the top-level decay,
+        i.e. that of the mother particle (nothing else would make sense).
+
         Examples
         --------
         >>> dm1 = DecayMode(0.0124, 'K_S0 pi0', model='PHSP')
